# Flytekit Hive Plugin

Flyte backend can be connected with various Hive services. Once enabled, it allows you to query a Hive service (e.g., Qubole) and retrieve typed schema (optionally).

To install the plugin, run the following command:

```bash
pip install flytekitplugins-hive
```

An [example](https://docs.flyte.org/projects/cookbook/en/latest/auto/integrations/external_services/hive/hive.html#sphx-glr-auto-integrations-external-services-hive-hive-py) can be found in the documentation.
